//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 2002
// 
// Unix.cc -- 
// 
// Author           : Peter A. Buhr
// Created On       : Mon Dec  2 22:46:18 2002
// Last Modified By : Peter A. Buhr
// Last Modified On : Fri Aug 12 17:24:57 2005
// Update Count     : 19
// 

#include <uC++.h>
//#include <uDebug.h>


extern "C" unsigned int sleep( unsigned int sec ) {
#ifdef __U_DEBUG_H__
    uDebugPrt( "sleep ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZ\n" );
#endif // __U_DEBUG_H__
    _Timeout( uDuration( sec, 0 ) );
    return 0;
} // sleep

extern "C" int usleep( unsigned int usec ) {
    _Timeout( uDuration( 0, usec ) );
    return 0;
} // usleep

extern "C" unsigned int alarm( unsigned int sec ) __THROW {
    uAbort( "alarm : not implemented" );
    return 0;
} // alarm


// Local Variables: //
// compile-command: "gmake install" //
// End: //
